#!/bin/sh

echo "post-install"

# App Central extend timeout, but the timeout seems be counted from post-install, not pre-install, so move "docker pull" to post-install.

docker pull postgres:12.13

# From 2.19.0 (Vaultwarden 1.21) can use same image.
docker pull vaultwarden/server:latest

echo "Completed docker pull"


CONTAINER_TEST=$(docker container ls -a | grep Vaultwarden | awk '{print $1}')

if [ ! -z $CONTAINER_TEST ]; then
	docker rm -f $CONTAINER_TEST
fi


BITWARDEN_DATA_PATH=/share/Docker/Bitwarden_pgsql

VAULTWARDEN_DATA_PATH=/share/Docker/Vaultwarden_pgsql

# From v2.19.0.r01, change to vaultwarden
if [ -e $BITWARDEN_DATA_PATH ]; then
	mv -f $BITWARDEN_DATA_PATH $VAULTWARDEN_DATA_PATH
fi


# enable ADMIN_TOKEN feature.
# Check if users already manually add token before or not, and also check if any previous saved token.
EXIST_TOKEN=

if [ -e $VAULTWARDEN_DATA_PATH/bw-data/bwadmintoken.txt ]; then
	EXIST_TOKEN=$(cat $VAULTWARDEN_DATA_PATH/bw-data/bwadmintoken.txt | awk '{print $1}')
elif [ -e $VAULTWARDEN_DATA_PATH/bw-data/config.json ]; then
	EXIST_TOKEN=$(grep \"admin_token\": $VAULTWARDEN_DATA_PATH/bw-data/config.json | awk '{print $2}' | sed 's/\"//g' | sed 's/\,//g')
fi

if [ ! -z $EXIST_TOKEN ]; then
	ADMINTOKEN=$EXIST_TOKEN
else
	ADMINTOKEN=$(openssl rand -base64 48)
fi


docker run -d --name=vaultwarden_pgsql \
	-e POSTGRES_USER=bitwarden \
	-e POSTGRES_PASSWORD=bitwarden \
	-e POSTGRES_DB=bitwardendb \
	-v /etc/localtime:/etc/localtime:ro \
	-v $VAULTWARDEN_DATA_PATH/db_data:/var/lib/postgresql/data:rw \
	--restart unless-stopped \
	postgres:12.13

sleep 5

docker create -i -t --name=Vaultwarden \
	-p 32301:80 \
	--link vaultwarden_pgsql:db \
	-e DATABASE_URL='postgresql://bitwarden:bitwarden@vaultwarden_pgsql/bitwardendb' \
	-e ENABLE_DB_WAL='false' \
	-e ROCKET_TLS='{certs="/ssl/ssl.crt",key="/ssl/ssl.key"}' \
	-e ADMIN_TOKEN=$ADMINTOKEN \
	-e LOG_FILE='/data/bitwarden_rs.log' \
	-e LOG_LEVEL=warn \
	-v /usr/builtin/etc/certificate/:/ssl/:ro \
	-v /etc/localtime:/etc/localtime:ro \
	-v $VAULTWARDEN_DATA_PATH/bw-data:/data:rw \
	--restart unless-stopped \
	vaultwarden/server:latest
	
	
docker start Vaultwarden
sleep 3

# Save the token if it's not existed
if [ ! -e $VAULTWARDEN_DATA_PATH/bw-data/bwadmintoken.txt ]; then
	echo "$ADMINTOKEN" >> $VAULTWARDEN_DATA_PATH/bw-data/bwadmintoken.txt
fi

case "$APKG_PKG_STATUS" in
	install)
		;;
	upgrade)
		oldim=$(docker images | grep vaultwarden/server | grep none | awk '{print $3}')
		echo $oldim
		
		if [ ! -z $oldim ]; then 
			docker rmi -f $oldim
		fi

		olddbim=$(docker images | grep postgres | grep none | awk '{print $3}')
		echo $olddbim
		
		if [ ! -z $olddbim ]; then 
			docker rmi -f $olddbim
		fi
		
		;;
	*)
		;;
esac

# The followings can be removed from next release.
dbimold=$(docker images | grep postgres | grep 12.9 | awk '{print $3}')
echo $dbimold
		
if [ ! -z $dbimold ]; then 
	docker rmi -f $dbimold
fi

exit 0
